==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/hco15.h <==
/* @lastChanged: "1998-05-12  7:06"

  * @filename:   hco002.h
  * @purpose:    "C++ Persistent Object TimeStamp"
  * @release:    7.1.0.0
  * @see:        "http://www.bea.sap-ag.de/doku/rel-7.1/gco10.html"
  *
  * @copyright:  "Copyright by   SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

#if !defined (__HCO15_H)
#define __HCO15_H

#define SEC_PER_HOUR 3600L  // 60*60

class cco15_DateTime
{
public:
  cco15_DateTime() { dtValue = 0; }
  cco15_DateTime( long year, long month, long day, long hour, long min, long sec );
    
  unsigned long getDTValue ( void ) const { return dtValue; }
  int seconds( void ) const { return dtValue%60; }
  int minutes( void ) const { return (dtValue/60)%60; }
  int hours  ( void ) const { return (dtValue/SEC_PER_HOUR)%24; }
  int day    ( void ) const;
  int month  ( void ) const;
  int year   ( void ) const;
private:
  unsigned long dtValue;
};

#endif // __HCO002_H

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/hco15.h <==
/* @lastChanged: "1998-05-12  7:06"

  * @filename:   hco002.h
  * @purpose:    "C++ Persistent Object TimeStamp"
  * @release:    7.1.0.0
  * @see:        "http://www.bea.sap-ag.de/doku/rel-7.1/gco10.html"
  *
  * @copyright:  "Copyright by   SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

#if !defined (__HCO15_H)
#define __HCO15_H

#define SEC_PER_HOUR 3600L  // 60*60

class AFX_EXT_CLASS cco15_DateTime
{
public:
  cco15_DateTime() { dtValue = 0; }
  cco15_DateTime( long year, long month, long day, long hour, long min, long sec );
    
  unsigned long getDTValue ( void ) const { return dtValue; }
  int seconds( void ) const { return dtValue%60; }
  int minutes( void ) const { return (dtValue/60)%60; }
  int hours  ( void ) const { return (dtValue/SEC_PER_HOUR)%24; }
  int day    ( void ) const;
  int month  ( void ) const;
  int year   ( void ) const;
private:
  unsigned long dtValue;
};

#endif // __HCO002_H
